/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package rozdeleniobrazku;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.imageio.ImageIO;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerModel;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 *
 * @author luboš
 */
public class Gui {

    private JFrame myFrame;
    private ImageCut imageCut;
    private JSpinner columnsSpinner;
    private JSpinner rowsSpinner;
    private JButton saveButton;
    private URL imageUrl = null;
    private SpinnerModel modelRows;
    private SpinnerModel modelColumns;
    private BufferedImage myImage;
    
    public Gui() {
        myFrame = new JFrame();
        myFrame.setTitle("Image Cut");
        myFrame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        try {
            imageUrl = Gui.class.getResource("/images/1890s_adding_machine.jpg");
            //imageUrl = new URL("http://upload.wikimedia.org/wikipedia/commons/thumb/2/28/1890s_adding_machine.jpg/440px-1890s_adding_machine.jpg");
            
            myImage = ImageIO.read(imageUrl);
            imageCut = new ImageCut(myImage);
            myFrame.add(imageCut);
        } catch (IOException ex) {
            System.err.println("Nepodařilo se načíst obrázek");
            System.err.println(ex.getMessage());
            System.exit(1);
        }

        myFrame.add(dolniPanel(), BorderLayout.SOUTH);
        myFrame.pack();

    }

    public void setVisible(boolean b) {
        myFrame.setVisible(b);
    }
    
    private JPanel dolniPanel() {
        JPanel panel = new JPanel();
        panel.add(new JLabel("rows:"));
        modelRows =
                new SpinnerNumberModel(1, //initial value
                1, //min
                10, //max
                1); // step
        rowsSpinner = new JSpinner(modelRows);
        rowsSpinner.addChangeListener(spinnerListener);
        rowsSpinner.setName("rows");
        panel.add(rowsSpinner);
        modelColumns =
                new SpinnerNumberModel(1, //initial value
                1, //min
                10, //max
                1); // step
        columnsSpinner = new JSpinner(modelColumns);
        columnsSpinner.addChangeListener(spinnerListener);
        columnsSpinner.setName("columns");
        panel.add(new JLabel("columns:"));
        panel.add(columnsSpinner);
        
        
        saveButton = new JButton("SAVE FILES");
        panel.add(saveButton);
        saveButton.addActionListener(saveFilesListener);

        return panel;
    }
    
    private ActionListener saveFilesListener = new ActionListener() {

        @Override
        public void actionPerformed(ActionEvent e) {
            int rows = (Integer)modelRows.getValue();
            int columns = (Integer)modelColumns.getValue();
            saveImageParts(myImage, columns, rows);
        }
    };
    
    private ChangeListener spinnerListener = new ChangeListener() {

        @Override
        public void stateChanged(ChangeEvent e) {
            JSpinner source = (JSpinner)e.getSource();
            int value = (Integer)source.getModel().getValue();
            String name = source.getName();
            if ("rows".equals(name)) {
                imageCut.setRows(value);
            }
            else if ("columns".equals(name)) {
                imageCut.setColumns(value);
            }
        }
    };
    
    private static void saveImageParts(BufferedImage image, int columns, int rows) {
        try {
            
            Dimension size = new Dimension(image.getWidth(), image.getHeight());
            int columnStep = size.width / columns;
            int marginLeft = (size.width - (columnStep * columns)) / 2;
            int rowStep = size.height / rows;
            int marginTop = (size.height - (rowStep * rows)) / 2;
            
            for (int i = 0; i < rows; i++) {
                for (int j = 0; j < columns; j++) {
                    BufferedImage subImage = image.getSubimage(
                            j * columnStep + marginLeft,
                            i * rowStep + marginTop,
                            columnStep,
                            rowStep
                            );
                    File file = new File(String.format("newimage_%02d%02d.jpg", i, j));
                    ImageIO.write(subImage, "jpg", file);
                }
            }
        }
        catch (IOException e) {
            System.out.println(e.getMessage());
            
        }
    }
    
}
